#[non_exhaustive]pub enum EntityError {
Show 26 variants
Lock(Error),
Database(Error),
SQLDatabase(DbErr),
KeycloakRequest(Error),
KeycloakError(KeycloakError),
DistributedLocksError(DistributedLocksError),
LockManagerError(LockManagerError),
SequenceManagerError(SequenceManagerError),
UnexpectedError(Error),
SerdeJson(Error),
IdConflict(String, String),
NameConflict(String, String),
FieldsConflict(String, String, Value),
Forbidden,
Internal,
NotFound,
RequiredFields,
Unauthorized(String),
NotFoundById(String, String),
NotFoundByField(String, String, String),
NotAllowed(String),
BadRequest(String, String),
NoId,
NotEmpty,
NotSameOwner,
Bson(String),
}Expand description
Errors that can occur during entity operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Lock(Error)
A unhandled Database error occurred.
Database(Error)
A unhandled Database error occurred.
SQLDatabase(DbErr)
A unhandled Database error occurred.
KeycloakRequest(Error)
Keycloak request failure.
KeycloakError(KeycloakError)
Keycloak error
DistributedLocksError(DistributedLocksError)
distributed locks error
LockManagerError(LockManagerError)
lock manager error
SequenceManagerError(SequenceManagerError)
sequence manager error
UnexpectedError(Error)
A unexpected error occured.
SerdeJson(Error)
Serialization/deserialization error.
IdConflict(String, String)
Conflicting error, because resource already exists.
NameConflict(String, String)
Conflicting error, because resource already exists.
FieldsConflict(String, String, Value)
Conflicting error, because resource already exists.
Forbidden
Forbidden because of missing session.
Internal
Internal server error.
NotFound
Resource not found.
RequiredFields
Required fields are missing.
Unauthorized user.
NotFoundById(String, String)
not found by id.
NotFoundByField(String, String, String)
not found by field.
NotAllowed(String)
not allowed
BadRequest(String, String)
bad request.
NoId
No id field in inserted entity.
NotEmpty
Query document cannot be empty.
NotSameOwner
List of ids only allowed with same owner.
Bson(String)
Bson could not be serialized.
Implementations
Sourceimpl EntityError
impl EntityError
Creates an unauthorized error for a user.
Creates an unauthorized error from a context that implements UserId.
Sourcepub fn name_conflict<T>(name: impl Into<String>) -> Self
pub fn name_conflict<T>(name: impl Into<String>) -> Self
Creates a name conflict error for the given type.
Sourcepub fn fields_conflict<T>(
name: impl Into<String>,
fields: impl Into<Value>,
) -> Self
pub fn fields_conflict<T>( name: impl Into<String>, fields: impl Into<Value>, ) -> Self
Creates a fields conflict error.
Sourcepub fn not_found_by_id<T>(id: impl Into<String>) -> Self
pub fn not_found_by_id<T>(id: impl Into<String>) -> Self
Creates a not found by ID error.
Sourcepub fn not_found_by_field<T>(
field: impl Into<String>,
value: impl Into<String>,
) -> Self
pub fn not_found_by_field<T>( field: impl Into<String>, value: impl Into<String>, ) -> Self
Creates a not found by field error.
Sourcepub fn bad_request(
err_type: impl Into<String>,
err_msg: impl Into<String>,
) -> Self
pub fn bad_request( err_type: impl Into<String>, err_msg: impl Into<String>, ) -> Self
Creates a bad request error.
Sourcepub fn not_allowed(err_msg: impl Into<String>) -> Self
pub fn not_allowed(err_msg: impl Into<String>) -> Self
Creates a not allowed error.