pub trait Create<T, C: UserId> {
// Required method
fn create(self, ctx: &C) -> EntityResult<T>;
}Expand description
Trait for entity creation logic.
Implement this trait on your entity types to define creation logic that validates and creates entities based on user context.
Required Methods
Sourcefn create(self, ctx: &C) -> EntityResult<T>
fn create(self, ctx: &C) -> EntityResult<T>
Creates an entity with the given context.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".